#! /usr/bin/env python3

from configparser import ConfigParser
import os, json, logging, logging.config

from bottle import run, route


servicePath = os.path.dirname(os.path.abspath(__file__))
confPath = os.path.join(servicePath, 'config.ini')


@route('/CSrest/rest/onlineorder/number', method='GET')
def returnOrdersNumber() -> str:
    logging.info(u'Получение запроса от кассы')
    conf = ConfigParser()
    conf.read(confPath)
    try:
        orders = conf.getint('main', 'orders')
    except:
        orders = 0
    answer = json.dumps({'ordersNumber' : orders})
    logging.info(u'Отправка ответа')
    logging.info(u'Тело ответа:\n' + str(answer))
    return answer

def main() -> None:
    logging.basicConfig(format = u'[%(asctime)s] %(levelname)s - %(message)s', level = logging.INFO,
            filename = u'/linuxcash/logs/current/onlineorder-server-test.log')
    logging.info(u'Старт сервиса')
    conf = ConfigParser()
    conf.read(confPath)
    try:
        host = conf.get('main', 'host')
    except:
        host = '0.0.0.0'
    try:
        port = conf.getint('main', 'port')
    except:
        port = 5000
    try:
        logging.info(u'Стартуем на %s:%s' % (host, port))
        run(host=host, port=port)
    except Exception as e:
        logging.error(e)

if __name__ == '__main__':
    main()
